DeveloperAppVersion

Struct DeveloperAppVersion 

pub struct DeveloperAppVersion {
    pub owner: Arc<String>,
    pub version_id: i64,
    pub version: Arc<String>,
    pub application_key: Arc<String>,
    pub delay_data: Option<bool>,
    pub subscription_required: bool,
    pub owner_managed: bool,
    pub active: bool,
    pub vendor_id: Option<Arc<String>>,
    pub vendor_secret: Option<Arc<String>>,
}
Describes a version of an external application

Fields

owner: Arc<String>

The sportex user who owns the specific version of the application

version_id: i64

The unique Id of the application version

version: Arc<String>

The version identifier string such as 1.0, 2.0. Unique for a given application.

application_key: Arc<String>

The unqiue application key associated with this application version

delay_data: Option<bool>

Indicates whether the data exposed by platform services as seen by this application key is /// delayed or realtime.

subscription_required: bool

Indicates whether the application version needs explicit subscription

owner_managed: bool

Indicates whether the application version needs explicit management by producers. /// A value of false indicates, this is a version meant for developer use.

active: bool

Indicates whether the application version is currently active

vendor_id: Option<Arc<String>>

Public unique string provided to the Vendor that they can use to pass to the Betfair API in order to identify themselves.

vendor_secret: Option<Arc<String>>

Private unique string provided to the Vendor that they pass with certain calls to confirm their identity. /// Linked to a particular App Key.

Implementations

Source

impl DeveloperAppVersion

pub fn builder() -> DeveloperAppVersionBuilder<((), (), (), (), (), (), (), (), (), ())>

Create a builder for building DeveloperAppVersion. On the builder, call .owner(...), .version_id(...), .version(...), .application_key(...), .delay_data(...)(optional), .subscription_required(...), .owner_managed(...), .active(...), .vendor_id(...)(optional), .vendor_secret(...)(optional) to set the values of the fields. Finally, call .build() to create the instance of DeveloperAppVersion.